@@ -35,7 +35,7 @@ class KoShapeManager;
 class KoToolProxy;
 class KoViewConverter;
 class KoShapeController;
-class KoShapeBasedDocumentBase;
+class KoShapeControllerBase;
 class KoCanvasController;
 class KoShape;
 class KoSnapGuide;
@@ -61,10 +61,10 @@ public:
 
     /**
      * The constructor.
-     * @param shapeBasedDocument the implementation of the shapeController that the
+     * @param shapeController the implementation of the shapeController that the
      *   application provides to allow shapes to be added in multiple views.
      */
-    explicit KoCanvasBase(KoShapeBasedDocumentBase *shapeBasedDocument, KoCanvasResourceManager *sharedResourceManager = 0);
+    explicit KoCanvasBase(KoShapeControllerBase *shapeController, KoCanvasResourceManager *sharedResourceManager = 0);
     ~KoCanvasBase() override;
 
 public:
@@ -244,7 +244,7 @@ public:
     void setCanvasController(KoCanvasController *controller);
 
 private:
-    // we need a KoShapeBasedDocumentBase so that it can work
+    // we need a KoShapeControllerBase so that it can work
     KoCanvasBase();
 
     class Private;
