@@ -657,36 +657,87 @@ bool KoSvgTextChunkShape::loadSvg(const KoXmlElement &e, SvgLoadingContext &cont
 }
 
 namespace {
-bool hasNextSibling(const KoXmlNode &node)
-{
-    if (!node.nextSibling().isNull()) return true;
 
-    KoXmlNode parentNode = node.parentNode();
-
-    if (!parentNode.isNull() &&
-        parentNode.isElement() &&
-        parentNode.toElement().tagName() == "tspan") {
-
-        return hasNextSibling(parentNode);
-    }
-
-    return false;
+QString cleanUpString(QString text) {
+    text.replace(QRegExp("[\\r\\n]"), "");
+    text.replace(QRegExp(" {2,}"), " ");
+    return text;
 }
 
-bool hasPreviousSibling(const KoXmlNode &node)
+enum Result {
+    FoundNothing,
+    FoundText,
+    FoundSpace
+};
+
+Result hasPreviousSibling(KoXmlNode node)
 {
-    if (!node.previousSibling().isNull()) return true;
+    while (!node.isNull()) {
+        if (node.isElement()) {
+            KoXmlElement element = node.toElement();
+            if (element.tagName() == "text") break;
+        }
 
-    KoXmlNode parentNode = node.parentNode();
 
-    if (!parentNode.isNull() &&
-        parentNode.isElement() &&
-        parentNode.toElement().tagName() == "tspan") {
+        while (!node.previousSibling().isNull()) {
+            node = node.previousSibling();
 
-        return hasPreviousSibling(parentNode);
+            while (!node.lastChild().isNull()) {
+                node = node.lastChild();
+            }
+
+            if (node.isText()) {
+                KoXmlText textNode = node.toText();
+                const QString text = cleanUpString(textNode.data());
+
+                if (!text.isEmpty()) {
+
+                    // if we are the leading whitespace, we should report that
+                    // we are the last
+
+                    if (text == " ") {
+                        return hasPreviousSibling(node) == FoundNothing ? FoundNothing : FoundSpace;
+                    }
+
+                    return text[text.size() - 1] != " " ? FoundText : FoundSpace;
+                }
+            }
+        }
+        node = node.parentNode();
     }
 
-    return false;
+    return FoundNothing;
+}
+
+Result hasNextSibling(KoXmlNode node)
+{
+    while (!node.isNull()) {
+        while (!node.nextSibling().isNull()) {
+            node = node.nextSibling();
+
+            while (!node.firstChild().isNull()) {
+                node = node.firstChild();
+            }
+
+            if (node.isText()) {
+                KoXmlText textNode = node.toText();
+                const QString text = cleanUpString(textNode.data());
+
+                // if we are the trailing whitespace, we should report that
+                // we are the last
+                if (text == " ") {
+                    return hasNextSibling(node) == FoundNothing ? FoundNothing : FoundSpace;
+                }
+
+                if (!text.isEmpty()) {
+                    return text[0] != " " ? FoundText : FoundSpace;
+                }
+            }
+        }
+        node = node.parentNode();
+    }
+
+    return FoundNothing;
 }
 }
 
@@ -699,20 +750,20 @@ bool KoSvgTextChunkShape::loadSvgTextNode(const KoXmlText &text, SvgLoadingConte
 
     d->loadContextBasedProperties(gc);
 
-    QString data = text.data();
+    QString data = cleanUpString(text.data());
 
-    data.replace(QRegExp("[\\r\\n]"), "");
-    data.replace(QRegExp("\\s{2,}"), " ");
+    const Result leftBorder = hasPreviousSibling(text);
+    const Result rightBorder = hasNextSibling(text);
 
-    if (data.startsWith(' ') && !hasPreviousSibling(text)) {
+    if (data.startsWith(' ') && leftBorder == FoundNothing) {
         data.remove(0, 1);
     }
 
-    if (data.endsWith(' ') && !hasNextSibling(text)) {
+    if (data.endsWith(' ') && rightBorder != FoundText) {
         data.remove(data.size() - 1, 1);
     }
 
-    if (data == " ") {
+    if (data == " " && (leftBorder == FoundNothing || rightBorder == FoundNothing)) {
         data = "";
     }
 
