@@ -362,7 +362,7 @@ protected:
     /**
      * Checks whether a src paint device can be used as source
      * of fast bitBlt operation. The result of the check may
-     * depend on whether color spaces coinside, whether there is
+     * depend on whether color spaces coincide, whether there is
      * any shift of tiles between the devices and etc.
      *
      * WARNING: This check must be done <i>before</i> performing any
@@ -721,7 +721,7 @@ public:
      * Create a keyframe channel for the content on this device.
      * @param id identifier for the channel
      * @param node the parent node for the channel
-     * @return keyframe channel
+     * @return keyframe channel or 0 if there is not one
      */
     KisRasterKeyframeChannel *createKeyframeChannel(const KoID &id);
 
@@ -793,7 +793,7 @@ public:
      * Create an iterator that will "artificially" extend the paint device with the
      * value of the border when trying to access values outside the range of data.
      *
-     * @param rc indicates the rectangle that trully contains data
+     * @param rc indicates the rectangle that truly contains data
      */
     KisRepeatVLineConstIteratorSP createRepeatVLineConstIterator(qint32 x, qint32 y, qint32 h, const QRect& _dataWidth) const;
 
@@ -842,6 +842,8 @@ public:
     void updateLodDataStruct(LodDataStruct *dst, const QRect &srcRect);
     void uploadLodDataStruct(LodDataStruct *dst);
 
+    void generateLodCloneDevice(KisPaintDeviceSP dst, const QRect &originalRect, int lod);
+
     void setProjectionDevice(bool value);
     void tesingFetchLodDevice(KisPaintDeviceSP targetDevice);
 
