@@ -387,8 +387,6 @@ void KisImageTest::testLayerComposition()
     QVERIFY(!newLayer2->visible());
 }
 
-#include "testutil.h"
-#include "kis_group_layer.h"
 #include "kis_transparency_mask.h"
 #include "kis_psd_layer_style.h"
 
@@ -1004,7 +1002,7 @@ void KisImageTest::testFlattenImage()
     TestUtil::ReferenceImageChecker img("flatten", "imagetest");
 
     {
-        KisLayerUtils::flattenImage(p.image);
+        KisLayerUtils::flattenImage(p.image, 0);
         QVERIFY(img.checkDevice(p.image->projection(), p.image, "00_initial"));
 
         p.undoStore->undo();
