@@ -216,7 +216,7 @@ public Q_SLOTS:
      * @brief createDocument creates a new document and image and registers
      * the document with the Krita application.
      *
-     * Unless you explicitly call Document::close() the document wil remain
+     * Unless you explicitly call Document::close() the document will remain
      * known to the Krita document registry. The document and its image will
      * only be deleted when Krita exits.
      *
@@ -327,6 +327,8 @@ add_document_to_window()
     // Internal only: for use with mikro.py
     static QObject *fromVariant(const QVariant& v);
 
+    static QString krita_i18n(const QString &text);
+
 private Q_SLOTS:
 
     void mainWindowAdded(KisMainWindow *window);
