@@ -146,6 +146,7 @@
 #include "KisWindowLayoutManager.h"
 #include <KisUndoActionsUpdateManager.h>
 #include "KisWelcomePageWidget.h"
+#include <QScreen>
 
 #include <mutex>
 
@@ -276,6 +277,7 @@ public:
     KConfigGroup windowStateConfig;
 
     QUuid workspaceBorrowedBy;
+    KisSignalAutoConnectionsStore screenConnectionsStore;
 
     KisActionManager * actionManager() {
         return viewManager->actionManager();
@@ -714,6 +716,14 @@ void KisMainWindow::addRecentURL(const QUrl &url)
                     ok = false; // it's in the tmp resource
                 }
             }
+
+            const QStringList templateDirs = KoResourcePaths::findDirs("templates");
+            for (QStringList::ConstIterator it = templateDirs.begin() ; ok && it != templateDirs.end() ; ++it) {
+                if (path.contains(*it)) {
+                    ok = false; // it's in the templates directory.
+                    break;
+                }
+            }
 #ifdef HAVE_KIO
             if (ok) {
                 KRecentDocument::add(QUrl::fromLocalFile(path));
@@ -2117,6 +2127,7 @@ void KisMainWindow::subWindowActivated()
         if (menu) {
             Q_FOREACH (QAction *action, menu->actions()) {
                 action->setShortcut(QKeySequence());
+                action->deleteLater();
             }
         }
     }
@@ -2674,7 +2685,28 @@ void KisMainWindow::moveEvent(QMoveEvent *e)
     const int newScreen = qApp->desktop()->screenNumber(e->pos());
 
     if (oldScreen != newScreen) {
-        KisConfigNotifier::instance()->notifyConfigChanged();
+        emit screenChanged();
+    }
+
+    if (d->screenConnectionsStore.isEmpty() || oldScreen != newScreen) {
+
+        d->screenConnectionsStore.clear();
+
+        QScreen *newScreenObject = 0;
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+        newScreenObject = qApp->screenAt(e->pos());
+#else
+        // TODO: i'm not sure if this pointer already has a correct value
+        // by the moment we get the event. It might not work on older
+        // versions of Qt
+        newScreenObject = qApp->primaryScreen();
+#endif
+
+        if (newScreenObject) {
+            d->screenConnectionsStore.addConnection(newScreenObject, SIGNAL(physicalDotsPerInchChanged(qreal)),
+                                                    this, SIGNAL(screenChanged()));
+        }
     }
 }
 
