@@ -22,14 +22,12 @@
 #include <QObject>
 #include "kis_types.h"
 
-
-
 class KisSafeDocumentLoader : public QObject
 {
     Q_OBJECT
 public:
     KisSafeDocumentLoader(const QString &path = "", QObject *parent = 0);
-    ~KisSafeDocumentLoader();
+    ~KisSafeDocumentLoader() override;
 
 public:
     void setPath(const QString &path);
