@@ -68,17 +68,18 @@ KisConfigWidget *EXRExport::createConfigurationWidget(QWidget *parent, const QBy
 
 KisImportExportFilter::ConversionStatus EXRExport::convert(KisDocument *document, QIODevice */*io*/,  KisPropertiesConfigurationSP configuration)
 {
+    Q_ASSERT(document);
+    Q_ASSERT(configuration);
+
     KisImageSP image = document->savingImage();
+    Q_ASSERT(image);
 
     EXRConverter exrConverter(document, !batchMode());
 
     KisImageBuilder_Result res;
 
-    if (configuration->getBool("flatten")) {
-        KisPaintDeviceSP pd = new KisPaintDevice(*image->projection());
-        KisPaintLayerSP l = new KisPaintLayer(image, "projection", OPACITY_OPAQUE_U8, pd);
-
-        res = exrConverter.buildFile(filename(), l);
+    if (configuration && configuration->getBool("flatten")) {
+        res = exrConverter.buildFile(filename(), image->rootLayer(), true);
     }
     else {
         res = exrConverter.buildFile(filename(), image->rootLayer());
