@@ -30,8 +30,8 @@ class exrImport : public KisImportExportFilter
 public:
     exrImport(QObject *parent, const QVariantList &);
     ~exrImport() override;
-public:
-    KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0) override;
+    bool supportsIO() const override { return false; }
+    KisImportExportFilter::ConversionStatus convert(KisDocument *document, QIODevice *io,  KisPropertiesConfigurationSP configuration = 0) override;
 };
 
 #endif
