@@ -28,9 +28,10 @@ class KisTIFFImport : public KisImportExportFilter
     Q_OBJECT
 public:
     KisTIFFImport(QObject *parent, const QVariantList &);
-    virtual ~KisTIFFImport();
+    ~KisTIFFImport() override;
+    bool supportsIO() const override { return false; }
 public:
-    virtual KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
+    KisImportExportFilter::ConversionStatus convert(KisDocument *document, QIODevice *io,  KisPropertiesConfigurationSP configuration = 0) override;
 };
 
 #endif
