@@ -39,12 +39,12 @@ class KisExperimentOpOption : public KisPaintOpOption
     Q_OBJECT
 public:
     KisExperimentOpOption();
-    ~KisExperimentOpOption();
+    ~KisExperimentOpOption() override;
 
-    void writeOptionSetting(KisPropertiesConfigurationSP setting) const;
-    void readOptionSetting(const KisPropertiesConfigurationSP setting);
+    void writeOptionSetting(KisPropertiesConfigurationSP setting) const override;
+    void readOptionSetting(const KisPropertiesConfigurationSP setting) override;
 
-    void lodLimitations(KisPaintopLodLimitations *l) const;
+    void lodLimitations(KisPaintopLodLimitations *l) const override;
 
 private Q_SLOTS:
     void enableSpeed(qreal value);
