@@ -55,6 +55,7 @@ ToolTransformArgs::ToolTransformArgs()
     KConfigGroup configGroup =  KSharedConfig::openConfig()->group("KisToolTransform");
     QString savedFilterId = configGroup.readEntry("filterId", "Bicubic");
     setFilterId(savedFilterId);
+    m_transformAroundRotationCenter = configGroup.readEntry("transformAroundRotationCenter", "0").toInt();
 
     m_editTransformPoints = false;
 }
@@ -68,12 +69,21 @@ void ToolTransformArgs::setFilterId(const QString &id) {
     }
 }
 
+void ToolTransformArgs::setTransformAroundRotationCenter(bool value)
+{
+    m_transformAroundRotationCenter = value;
+
+    KConfigGroup configGroup =  KSharedConfig::openConfig()->group("KisToolTransform");
+    configGroup.writeEntry("transformAroundRotationCenter", int(value));
+}
+
 void ToolTransformArgs::init(const ToolTransformArgs& args)
 {
     m_mode = args.mode();
     m_transformedCenter = args.transformedCenter();
     m_originalCenter = args.originalCenter();
     m_rotationCenterOffset = args.rotationCenterOffset();
+    m_transformAroundRotationCenter = args.transformAroundRotationCenter();
     m_cameraPos = args.m_cameraPos;
     m_aX = args.aX();
     m_aY = args.aY();
@@ -111,6 +121,11 @@ ToolTransformArgs::ToolTransformArgs(const ToolTransformArgs& args)
     init(args);
 }
 
+KisToolChangesTrackerData *ToolTransformArgs::clone() const
+{
+    return new ToolTransformArgs(*this);
+}
+
 ToolTransformArgs& ToolTransformArgs::operator=(const ToolTransformArgs& args)
 {
     clear();
@@ -133,6 +148,7 @@ bool ToolTransformArgs::operator==(const ToolTransformArgs& other) const
         m_transformedCenter == other.m_transformedCenter &&
         m_originalCenter == other.m_originalCenter &&
         m_rotationCenterOffset == other.m_rotationCenterOffset &&
+        m_transformAroundRotationCenter == other.m_transformAroundRotationCenter &&
         m_aX == other.m_aX &&
         m_aY == other.m_aY &&
         m_aZ == other.m_aZ &&
@@ -209,6 +225,7 @@ ToolTransformArgs::ToolTransformArgs(TransformMode mode,
                                      QPointF transformedCenter,
                                      QPointF originalCenter,
                                      QPointF rotationCenterOffset,
+                                     bool transformAroundRotationCenter,
                                      double aX, double aY, double aZ,
                                      double scaleX, double scaleY,
                                      double shearX, double shearY,
@@ -222,6 +239,7 @@ ToolTransformArgs::ToolTransformArgs(TransformMode mode,
     m_transformedCenter = transformedCenter;
     m_originalCenter = originalCenter;
     m_rotationCenterOffset = rotationCenterOffset;
+    m_transformAroundRotationCenter = transformAroundRotationCenter;
     m_cameraPos = QVector3D(0,0,1024);
     m_aX = aX;
     m_aY = aY;
@@ -318,6 +336,7 @@ void ToolTransformArgs::toXML(QDomElement *e) const
         KisDomUtils::saveValue(&freeEl, "transformedCenter", m_transformedCenter);
         KisDomUtils::saveValue(&freeEl, "originalCenter", m_originalCenter);
         KisDomUtils::saveValue(&freeEl, "rotationCenterOffset", m_rotationCenterOffset);
+        KisDomUtils::saveValue(&freeEl, "transformAroundRotationCenter", m_transformAroundRotationCenter);
 
         KisDomUtils::saveValue(&freeEl, "aX", m_aX);
         KisDomUtils::saveValue(&freeEl, "aY", m_aY);
@@ -386,6 +405,7 @@ ToolTransformArgs ToolTransformArgs::fromXML(const QDomElement &e)
             KisDomUtils::loadValue(freeEl, "transformedCenter", &args.m_transformedCenter) &&
             KisDomUtils::loadValue(freeEl, "originalCenter", &args.m_originalCenter) &&
             KisDomUtils::loadValue(freeEl, "rotationCenterOffset", &args.m_rotationCenterOffset) &&
+            KisDomUtils::loadValue(freeEl, "transformAroundRotationCenter", &args.m_transformAroundRotationCenter) &&
 
             KisDomUtils::loadValue(freeEl, "aX", &args.m_aX) &&
             KisDomUtils::loadValue(freeEl, "aY", &args.m_aY) &&
